// ***********************************************************
// Persistence Of Vision Ray Tracer Scene Description File
// File name  : pestillo.pov
// Version    : 3.7
// Description: locked door
// Date       : Jan 2005 - revised for 3.7 Oct-2012
// Author     : Jaime Vives Piqueres
// Scene scale: 1 pov unit = 1 cm
// ***********************************************************

#include "colors.inc"
#include "textures.inc"
#include "stones.inc"
#include "metals.inc"
#include "woods.inc"
#include "functions.inc"

// *** control center ***
#declare use_blur =7*5;  // blur samples (0=off)
#declare use_area   =1;
#declare use_oldwood=1;
#ifndef(use_radiosity)
#declare use_radiosity =2;
#end
#declare rad_brightness=1;
global_settings{
// assumed_gamma 1.0
 #if (use_radiosity)
  #include "i_rad.inc"
 #end
}
#default{texture{finish{ambient 0}}}

// *** CIE & LIGHTSYS ***
#include "CIE.inc"
CIE_ColorSystemWhitepoint(sRGB_ColSys,Blackbody2Whitepoint(5500))
#include "lightsys.inc"          
#include "espd_lightsys.inc"  // light spectrums
#include "rspd_jvp.inc"       // material samples
#declare Lightsys_Brightness=.5;


// ****************************************************
// *** MACRO TO PROCEDURALIZE PHOTOGRAPHIC TEXTURES ***
// ****************************************************
#macro Proceduralize(
  img_name,		// image file name (jpeg only)
  img_f,img_t,		// filter and transmit amount
  img_f1,img_f2,        // two finishes to blend
  img_bs1,img_bs2,     	// bump_maps sizes
  img_sc,		// scale
  img_tsp,img_tsw,	// textures separation point and width
  img_turb,img_turb_l,  // turbulence amount and lambda
  t_under		// underliying texture
 )

 #local p_img=
 pigment{
  image_map{
   jpeg img_name 
   #if (img_f>0)
    filter all img_f 
   #end
   #if (img_t>0)
    transmit all img_t
   #end
  }
 } 
 #local n_img=
 normal{
  bump_map{
   jpeg img_name
  }
 }
 #local t1=
 texture{
  pigment{p_img}
  finish{img_f1}
  normal{n_img img_bs1}
 }
 #local t2=
 texture{
  pigment{p_img}
  finish{img_f2}
  normal{n_img img_bs2}
 }
 #if ((img_f+img_t)>0)
  #local t1= 
  texture{t_under}
  texture{t1}
  #local t2= 
  texture{t_under}
  texture{t2}
 #end
 #local f_img=
 function{
  pigment{p_img}
 }
 #local t_result=
 texture{
  function{f_img(x,y,z).gray}
//  image_pattern{jpeg img_name}
  texture_map{
   [0.0 t1]
   #if (img_tsp>0)
   [img_tsp t1]
   [img_tsp+img_tsw t2]
   #end
   [1.0 t2]
  }
  #if (img_turb>0)
  warp{
   turbulence img_turb 
   lambda img_turb_l
  }
  #end
  translate -.5
  scale img_sc
 }
 #local dummy=0; // so POV doesn't takes the following as another layer... :)

 t_result

#end


// **********************
// *** METAL TEXTURES ***
// **********************
#declare t_base_pestillo=texture{pigment{SteelBlue*.5+Gray20}}
#declare t_base_candado=texture{pigment{Green*.1+Yellow*.3+Gray20}}
#declare t_base_tirador=texture{pigment{Bronze*.5+Gray20}}
#if (use_radiosity<2)    
#declare im="copper.jpg" 
#declare im_sc=3;
#declare im_f=.5;
#declare bs=-pi;
#declare f1=finish{specular .33 metallic}
#declare f2=finish{F_MetalB metallic reflection {0,1} ambient 0}
#declare t_metal_pestillo_pulido=
texture{
 Proceduralize(im,0,.33,f1,f2,bs,bs,im_sc,0,0,.5,2.5,t_base_pestillo)
}
#declare t_metal_pestillo_oxidado=
texture{
 Proceduralize(im,0,.33,f1,f2,bs,bs,im_sc,.5,.1,.1,3,t_base_pestillo)
}
#declare t_metal_candado_pulido=
texture{
 Proceduralize(im,0,.33,f1,f2,bs,bs,im_sc,0,0,.5,2.5,t_base_pestillo)
}
#declare t_metal_candado_oxidado=
texture{
 Proceduralize(im,0,.33,f1,f2,bs,bs,im_sc*<8,.7,1>,.4,.3,.1,3,t_base_candado)
}
#declare t_metal_tirador=
texture{
 Proceduralize(im,0,.33,f1,f2,bs,bs,im_sc,0,0,.5,2.5,t_base_tirador)
}
#else
#declare t_metal_pestillo_pulido=
texture{t_base_pestillo}
#declare t_metal_pestillo_oxidado=
texture{t_base_pestillo}
#declare t_metal_candado_pulido=
texture{t_base_candado}
#declare t_metal_candado_oxidado=
texture{t_base_candado}
#declare t_metal_tirador=
texture{t_base_tirador}
#end


// ****************
// *** PESTILLO ***
// ****************
#include "i_pestillo.inc"
union{
 object{pest_chapa}
 object{pest_pasador}
 scale <-1,1,1>
 scale 6
 translate 5*y
}

// *** TIRADOR ***
#include "i_doorhandle.inc"
object{door_handle
 scale 8
 rotate 180*y
 translate <12,-9,-2.5>
}

// *** CANDADO ***
#include "i_aro.inc"
object{aro scale 3 rotate 90*x translate <-8,-3,-6>}
object{aro scale 3 rotate 90*x translate <-4.5,-3,-4>}
#include "i_candado2.inc"
object{candado2
 scale <-1,1,1>
 rotate 180*y
 scale 5
 rotate 30*x
 rotate -41*y
 rotate 6*z
 translate <-4,-9.5,-4.5>
}


// *** DOOR ***
#if (use_radiosity<2)    
// textures
#declare im="P7143300.JPG" #declare im_sc=80;
#declare f1=finish{}
#declare f2=finish{Shiny}
#declare t_wood_base=
texture{
// T_Wood18 
 T_Wood8
// T_Wood15
// T_Wood2
// T_Wood5
// T_Wood6
// T_Wood7
 rotate 90*x scale 4/im_sc finish{ambient 0}
}
#declare t_wood=
texture{
 Proceduralize(im,.33,.33,f2,f1,1,1,im_sc,.7,0,0,0,t_wood_base)
 rotate 180*y
 translate -1.9*x
 translate -20*y
}
#else
#declare t_wood=
texture{pigment{Tan}}
#end
// old wood board
#if (use_oldwood)    
#declare board=
isosurface{
  function{
   f_rounded_box(x,y,z,.05,.95,.95,.95) 
   - f_granite(x*5,y*4,z*1)*.05
  }
  max_gradient 2
  contained_by{box{-1,1}}
  scale .52
}
#declare board2=
isosurface{
  function{
   f_rounded_box(x,y,z,.05,.5,.95,.95) 
   - f_granite(x*2.5,y*4,z*1)*.05
  }
  max_gradient 2
  contained_by{box{-1,1}}
  scale .52
}
#else
#declare board=
 box{-.5,.5}
#declare board2=
 box{-.5,.5 scale <.5,1,1>}
#end
#declare door=
union{
 object{board
  scale <32,180,6>
  texture{t_wood translate 24*x}
  translate (-55+16)*x
  translate 1*z
 }
 object{board2
  scale <16,180,6>
  texture{t_wood translate 5*x}
  translate (-55-4)*x
  translate -3*z
 }
 translate <45,0,2.1>
}
object{door}

// *** WALL ***
#if (use_radiosity<2)    
#declare im="PA180081.JPG" #declare im_sc=100;
#declare t_wall=
texture{
 pigment{
  image_map{
   jpeg im
  }
 } 
 normal{
  bump_map{
   jpeg im 
   bump_size 1
  }
 }
 scale im_sc
}
#else
#declare t_wall=
texture{pigment{Gray}}
#end
#if (use_radiosity<2)    
isosurface{
  function{
   f_rounded_box(x,y,z,.05,.95,.95,.95) 
   - f_granite(x*5,y*10,z*2)*.05
  }
  max_gradient 2
  contained_by{box{-1,1}}
  scale .52
#else
box{-.5,.5
#end
 scale <32,180,6>
 texture{t_wall rotate 180*y translate -50*y}
 translate <-55-8-16,0,1>
 translate <45,0,2.1>
}

// test light
#declare r_l=seed(159); //157
#declare cdi=Daylight(6500);
union{
 light_source{
  0
  Light_Color(cdi,800*3)
  #if (use_area)
  area_light <12,0,0>,<0,0,12>,4,4 jitter adaptive 1 orient circular
  #end
  Light_Fading()
 }
 sphere{0,1 hollow
  pigment { color rgbf<1, 1, 1, 1> }
  finish { ambient 0 diffuse 0 }
  interior{media{emission cdi*800*3}}
  scale <2,3,2>
 }
 translate <-200+400*rand(r_l),110,-200*rand(r_l)>
}

box{-.5,.5 scale <500,250,500>
 pigment{White}
 finish{diffuse 1}
}



// **************
// *** camera ***
// **************
#declare cl=<38,2,-52>;
#declare la=<2,-1.5,0>;
camera{
 location cl
 up 2.4*y
 right 3.2*x
 direction 5*z
 look_at la
 #if (use_blur)
 focal_point <-4,-9.5,-4.5> //la
 aperture pi/2
 blur_samples use_blur
 #end
}

